Welcome to Fabric!
==================

Fabric is a high level Python (2.7, 3.4+) library designed to execute shell
commands remotely over SSH, yielding useful Python objects in return. It builds
on top of `Invoke <http://pyinvoke.org>`_ (subprocess command execution and
command-line features) and `Paramiko <http://paramiko.org>`_ (SSH protocol
implementation), extending their APIs to complement one another and provide
additional functionality.

For a high level introduction, including example code, please see
`our main project website <http://fabfile.org>`_; or for detailed API docs, see
`the versioned API website <http://docs.fabfile.org>`_.
